import hashlib

# A way to get unquote working with python 2 and 3
try:
    from urllib import unquote
except ImportError:
    from urllib.parse import unquote

from gi.repository import GObject, Gtk, Thunarx

class ThunarxPropertyPagePlugin(GObject.GObject, Thunarx.PropertyPageProvider):
    def __init__(self):
        pass

    def get_property_pages(self, files):
        if len(files) != 1:
            return
        
        file = files[0]
        if file.get_uri_scheme() != 'file':
            return

        if file.is_directory():
            return
        
        filename = unquote(file.get_uri()[7:])

        hbox = Gtk.HBox(0, False)
        hbox.show()

        label = Gtk.Label('MD5Sum:')
        label.show()
        hbox.pack_start(label, True, True, 0)

        value_label = Gtk.Label()
        hbox.pack_start(value_label, True, True, 0)

        md5sum = hashlib.md5(filename.encode("utf-8")).hexdigest()
        value_label.set_text(md5sum)
        value_label.show()

        page = Thunarx.PropertyPage()
        page.set_label("MD5")
        page.add(hbox)

        return [page]



from gi.repository import GObject, Gtk, Thunarx

class ThunarxMenuProviderPlugin(GObject.GObject, Thunarx.MenuProvider):
    def __init__(self):
        pass
    
    def get_file_menu_items(self, window, files):
        item = Thunarx.MenuItem(name="TMP:TestFileAction", label="Python File Action", tooltip='', icon=Gtk.STOCK_FILE)
        item.connect("activate", self.__do_something, window)

        return [item]

    def get_folder_menu_items(self, window, folder):
        return [Thunarx.MenuItem(name="TMP:TestFolderAction", label="Python Folder Action", tooltip='', icon=Gtk.STOCK_OPEN)]

    def __do_something(self, item, window):
        print "Doing something"



from gi.repository import GObject, Gtk, Thunarx

class ThunarxSubMenuProviderPlugin(GObject.GObject, Thunarx.MenuProvider):
    def __init__(self):
        pass
    
    def get_file_menu_items(self, window, files):
        item = Thunarx.MenuItem(name="TMP:Item1", label="Python File Action", tooltip='', icon=Gtk.STOCK_FILE)

        submenu = Thunarx.Menu()
        subitem1 = Thunarx.MenuItem(name='TMP::Subitem1', 
                                         label='Subitem1', 
                                         tooltip='First tip',
                                         icon=Gtk.STOCK_DND)
        subitem1.connect("activate", self.__subitem1_callback, window)
        submenu.append_item(subitem1)

        subitem2 = Thunarx.MenuItem(name='TMP::Subitem2', 
                                         label='Subitem2', 
                                         tooltip='Second tip',
                                         icon=Gtk.STOCK_FULLSCREEN)
        subitem2.connect("activate", self.__subitem2_callback, window)
        submenu.append_item(subitem2)
                                         
        item.set_menu(submenu)
        
        item2 = Thunarx.MenuItem(name='TMP::Item2', 
                                         label='Another item', 
                                         tooltip='',
                                         icon=Gtk.STOCK_OK)
    
        return item,item2

    def __subitem1_callback(self, item, window):
        print("Subitem1 call")
        
    def __subitem2_callback(self, item, window):
        print("Subitem2 call")



from gi.repository import GObject, Gtk, Thunarx

class ThunarxPythonRenamer(Thunarx.Renamer):
    __gtype_name__ = "ThunarxPythonRenamer"
    prefix = GObject.property(type=str)
    
    def __init__(self):
        Thunarx.Renamer.__init__(self)

        # Set properties to be saved in the settings files
        self.set_property("prefix", "__")
        
        self.set_name("Example Python Renamer 2")
        self.set_help_url("http://www.google.com")
     
        hbox = Gtk.HBox(0, False)
        
        label = Gtk.Label("Prefix:")
        hbox.pack_start(label, False, False, 0)
        
        self.entry = Gtk.Entry()
        self.entry.set_text(self.get_property("prefix"))
        self.entry.connect("changed", self.entry_changed)
        hbox.pack_start(self.entry, False, False, 0)
        
        label.show()
        self.entry.show()
        self.add(hbox)
        hbox.show()

    def do_process(self, file, text, index):
        prefix = self.entry.get_text()
        return prefix + text

    def entry_changed(self, widget):
        self.set_property("prefix", widget.get_text())
        
        # Emitting this will cause the do_process method to be called
        self.emit("changed")

    def do_get_menu_items(self, window, files):
        return [Thunarx.MenuItem(name="TPR:SomeAction", label="Some Action", tooltip=None, icon=Gtk.STOCK_OPEN)]

    def do_load(self, settings):
        """
        Loads settings saved in ~/.config/Thunar/renamerrc
        """
        if settings.haskey("Prefix"):
            self.set_property("prefix", settings["Prefix"])
            self.entry.set_text(self.get_property("prefix"))

    def do_save(self, settings):
        """
        If do_save is overriden, you must rebuild the settings dictionary and then
        return it.
        """
        settings["Prefix"] = self.get_property("prefix")
        return settings

class ThunarxRenamerPlugin(GObject.GObject, Thunarx.RenamerProvider):
    def __init__(self):
        pass
    
    def get_renamers(self):
        return [ThunarxPythonRenamer()]



from gi.repository import GObject, Gtk, Thunarx

class DialogExample(Gtk.Dialog):
    def __init__(self, parent):
        Gtk.Dialog.__init__(self, "My Dialog", parent, 0,
            (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
             Gtk.STOCK_OK, Gtk.ResponseType.OK))

        self.set_default_size(150, 100)
        self.set_transient_for(parent)

        label = Gtk.Label("This is a dialog to display additional information")

        box = self.get_content_area()
        box.add(label)
        self.show_all()

class ThunarxPreferencesPlugin(GObject.GObject, Thunarx.PreferencesProvider):
    def __init__(self):
        pass
    
    def get_preferences_menu_items(self, window):
        item = Thunarx.MenuItem(name="TPP:PrefItem", label="My Example Preferences", tooltip=None, icon=None)
        item.connect("activate", self.__open_preferences, window)
        return item,
    
    def __open_preferences(self, action, window):
        dialog = DialogExample(window)
        response = dialog.run()
        dialog.destroy()
